<?php

namespace Litecms\Content\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Content\Http\Requests\ContentRequest;
use Litecms\Content\Models\Content;

/**
 * Admin web controller class.
 */
class ContentWorkflowController extends BaseController
{

    /**
     * Workflow controller function for content.
     *
     * @param Model   $content
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ContentRequest $request, Content $content, $step)
    {

        try {

            $content->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('content::content.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/content/content/' . $content->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/content/content/' . $content->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for content.
     *
     * @param Model   $content
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Content $content, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $content->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('content::content.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('content::admin.content.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('content::admin.content.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('content::admin.content.message', $data)->render();

        }

    }
}
