<?php

namespace Litecms\Content\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\Content\Models\Content;

class ContentAction
{
    /**
     * Perform the complete action.
     *
     * @param Content $content
     *
     * @return Content
     */
    public function complete(Content $content)
    {
        try {
            $content->status = 'complete';
            return $content->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Content $content
     *
     * @return Content
     */public function verify(Content $content)
    {
        try {
            $content->status = 'verify';
            return $content->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Content $content
     *
     * @return Content
     */public function approve(Content $content)
    {
        try {
            $content->status = 'approve';
            return $content->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Content $content
     *
     * @return Content
     */public function publish(Content $content)
    {
        try {
            $content->status = 'publish';
            return $content->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Content $content
     *
     * @return Content
     */
    public function archive(Content $content)
    {
        try {
            $content->status = 'archive';
            return $content->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Content $content
     *
     * @return Content
     */
    public function unpublish(Content $content)
    {
        try {
            $content->status = 'unpublish';
            return $content->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
