<?php

namespace Litecms\Content\Workflow;

use Litecms\Content\Models\Content;
use Validator;

class ContentValidator
{

    /**
     * Determine if the given content is valid for complete status.
     *
     * @param Content $content
     *
     * @return bool / Validator
     */
    public function complete(Content $content)
    {
        return Validator::make($content->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given content is valid for verify status.
     *
     * @param Content $content
     *
     * @return bool / Validator
     */
    public function verify(Content $content)
    {
        return Validator::make($content->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given content is valid for approve status.
     *
     * @param Content $content
     *
     * @return bool / Validator
     */
    public function approve(Content $content)
    {
        return Validator::make($content->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given content is valid for publish status.
     *
     * @param Content $content
     *
     * @return bool / Validator
     */
    public function publish(Content $content)
    {
        return Validator::make($content->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given content is valid for archive status.
     *
     * @param Content $content
     *
     * @return bool / Validator
     */
    public function archive(Content $content)
    {
        return Validator::make($content->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given content is valid for unpublish status.
     *
     * @param Content $content
     *
     * @return bool / Validator
     */
    public function unpublish(Content $content)
    {
        return Validator::make($content->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
